@@ -8,7 +8,7 @@ import (
 	"syscall"
 	"time"
 
-	"k8s.io/klog"
+	"k8s.io/klog/v2"
 
 	utilruntime "k8s.io/apimachinery/pkg/util/runtime"
 
@@ -52,10 +52,9 @@ func newEgressIPWatcher(oc *ovsController, localIP string, masqueradeBit *int32)
 func (eip *egressIPWatcher) Start(networkInformers networkinformers.SharedInformerFactory, iptables *NodeIPTables) error {
 	eip.iptables = iptables
 
-	updates := make(chan *egressVXLANNode)
+	updates := make(chan struct{}, 1)
 	eip.vxlanMonitor = newEgressVXLANMonitor(eip.oc.ovs, eip.tracker, updates)
 	go eip.watchVXLAN(updates)
-
 	eip.tracker.Start(networkInformers.Network().V1().HostSubnets(), networkInformers.Network().V1().NetNamespaces())
 	return nil
 }
@@ -87,6 +86,8 @@ func (eip *egressIPWatcher) Synced() {
 			}
 		}
 	}
+
+	eip.iptables.SyncEgressIPRules()
 }
 
 func egressIPLabel(link netlink.Link) (string, error) {
@@ -246,8 +247,10 @@ func (eip *egressIPWatcher) releaseEgressIP(egressIP, mark string) error {
 	return nil
 }
 
-func (eip *egressIPWatcher) watchVXLAN(updates chan *egressVXLANNode) {
-	for node := range updates {
-		eip.tracker.SetNodeOffline(node.nodeIP, node.offline)
+func (eip *egressIPWatcher) watchVXLAN(updates chan struct{}) {
+	for range updates {
+		for _, node := range eip.vxlanMonitor.GetUpdates() {
+			eip.tracker.SetNodeOffline(node.nodeIP, node.offline)
+		}
 	}
 }
